.. tylisten documentation master file, created by
   sphinx-quickstart on Sun Nov  5 15:40:52 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tylisten's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tylisten/hookspec
   tylisten/futstore


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
